@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -56,6 +56,7 @@ class DistanceCalculatorServiceGrpcTransport(DistanceCalculatorServiceTransport)
             quota_project_id: Optional[str] = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             always_use_jwt_access: Optional[bool] = False,
+            api_audience: Optional[str] = None,
             ) -> None:
         """Instantiate the transport.
 
@@ -151,6 +152,7 @@ class DistanceCalculatorServiceGrpcTransport(DistanceCalculatorServiceTransport)
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -255,9 +257,38 @@ class DistanceCalculatorServiceGrpcTransport(DistanceCalculatorServiceTransport)
             )
         return self._stubs['calculate_distance']
 
+    @property
+    def batch_calculate_distance(self) -> Callable[
+            [service.BatchDistanceRequest],
+            service.BatchDistanceResponse]:
+        r"""Return a callable for the batch calculate distance method over gRPC.
+
+        Returns:
+            Callable[[~.BatchDistanceRequest],
+                    ~.BatchDistanceResponse]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if 'batch_calculate_distance' not in self._stubs:
+            self._stubs['batch_calculate_distance'] = self.grpc_channel.unary_unary(
+                '/oceanbolt.com.distancecalculator.v3.DistanceCalculatorService/BatchCalculateDistance',
+                request_serializer=service.BatchDistanceRequest.serialize,
+                response_deserializer=service.BatchDistanceResponse.deserialize,
+            )
+        return self._stubs['batch_calculate_distance']
+
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
+
 __all__ = (
     'DistanceCalculatorServiceGrpcTransport',
 )
