@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -356,6 +356,7 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def get_dry_dock_stays(self,
@@ -368,7 +369,6 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
         r"""GetDryDockStays retrives individual historical dry
         dock stays
 
-
         .. code-block:: python
 
             from oceanbolt.com import drydock_v3
@@ -433,7 +433,6 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
         r"""GetDryDockTimeseries retrieves dry dock timeseries data for a
         specified list of port_ids/segments
 
-
         .. code-block:: python
 
             from oceanbolt.com import drydock_v3
@@ -498,7 +497,6 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
         r"""GetDryDockWeb retrieves current and live dry dock data for a
         specified list of port_ids/segments
 
-
         .. code-block:: python
 
             from oceanbolt.com import drydock_v3
@@ -563,7 +561,6 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
         r"""GetDryDockVessels retrieves list of currently active dry dock
         stays for a specified list of port_ids/segments
 
-
         .. code-block:: python
 
             from oceanbolt.com import drydock_v3
@@ -633,6 +630,9 @@ class DrydockServiceClient(metaclass=DrydockServiceClientMeta):
 
 
 
+
+
+
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
