@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -356,6 +356,7 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_segments(self,
@@ -494,7 +495,6 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         r"""ListZonesWithPolygons retrieves all zones with
         Polygons
 
-
         .. code-block:: python
 
             from oceanbolt.com import entities_v3
@@ -748,7 +748,6 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         r"""ListRegionsWithPolygons retrives all regions with geo
         polygons
 
-
         .. code-block:: python
 
             from oceanbolt.com import entities_v3
@@ -1007,6 +1006,9 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
 
 
+
+
+
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
