@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -356,6 +356,7 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def get_port_calls(self,
@@ -372,7 +373,6 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
         port calls to return per query, default is 50 and
         maximum is 2000.
 
-
         .. code-block:: python
 
             from oceanbolt.com import portcalls_v3
@@ -438,7 +438,6 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
         r"""GetPortCallTimeseries retrieves aggregated counts for
         port calls for a set of request params.
 
-
         .. code-block:: python
 
             from oceanbolt.com import portcalls_v3
@@ -510,7 +509,6 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
         calls to return per query, default is 50 and maximum is
         2000.
 
-
         .. code-block:: python
 
             from oceanbolt.com import portcalls_v3
@@ -568,6 +566,70 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
         # Done; return the response.
         return response
 
+    def get_vessels_in_port(self,
+            request: Union[service.GetVesselsInPortRequest, dict] = None,
+            *,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
+            timeout: float = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+            ) -> service.GetVesselsInPortResponse:
+        r"""GetVesselsInPort lists all vessels that were within a
+        port (or related anchorages) at a certain time.
+
+        .. code-block:: python
+
+            from oceanbolt.com import portcalls_v3
+
+            def sample_get_vessels_in_port():
+                # Create a client
+                client = portcalls_v3.PortCallServiceClient()
+
+                # Initialize request argument(s)
+                request = portcalls_v3.GetVesselsInPortRequest(
+                )
+
+                # Make the request
+                response = client.get_vessels_in_port(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.portcalls_v3.types.GetVesselsInPortRequest, dict]):
+                The request object. Request object for GetVesselsInPort
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            oceanbolt.com.portcalls_v3.types.GetVesselsInPortResponse:
+                Response object for GetVesselsInPort
+        """
+        # Create or coerce a protobuf request object.
+        # Minor optimization to avoid making a copy if the user passes
+        # in a service.GetVesselsInPortRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, service.GetVesselsInPortRequest):
+            request = service.GetVesselsInPortRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.get_vessels_in_port]
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     def __enter__(self):
         return self
 
@@ -583,6 +645,9 @@ class PortCallServiceClient(metaclass=PortCallServiceClientMeta):
 
 
 
+
+
+
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
