@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -99,6 +99,7 @@ class PortCallServiceGrpcAsyncIOTransport(PortCallServiceTransport):
             quota_project_id=None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             always_use_jwt_access: Optional[bool] = False,
+            api_audience: Optional[str] = None,
             ) -> None:
         """Instantiate the transport.
 
@@ -194,6 +195,7 @@ class PortCallServiceGrpcAsyncIOTransport(PortCallServiceTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -315,6 +317,33 @@ class PortCallServiceGrpcAsyncIOTransport(PortCallServiceTransport):
             )
         return self._stubs['get_port_particulars']
 
+    @property
+    def get_vessels_in_port(self) -> Callable[
+            [service.GetVesselsInPortRequest],
+            Awaitable[service.GetVesselsInPortResponse]]:
+        r"""Return a callable for the get vessels in port method over gRPC.
+
+        GetVesselsInPort lists all vessels that were within a
+        port (or related anchorages) at a certain time.
+
+        Returns:
+            Callable[[~.GetVesselsInPortRequest],
+                    Awaitable[~.GetVesselsInPortResponse]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if 'get_vessels_in_port' not in self._stubs:
+            self._stubs['get_vessels_in_port'] = self.grpc_channel.unary_unary(
+                '/oceanbolt.com.portcalls.v3.PortCallService/GetVesselsInPort',
+                request_serializer=service.GetVesselsInPortRequest.serialize,
+                response_deserializer=service.GetVesselsInPortResponse.deserialize,
+            )
+        return self._stubs['get_vessels_in_port']
+
     def close(self):
         return self.grpc_channel.close()
 
