@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
 #
 import proto  # type: ignore
 
+from google.protobuf import timestamp_pb2  # type: ignore
 from google.protobuf import wrappers_pb2  # type: ignore
 from oceanbolt.com.ptypes.filters import vessel_filter_pb2  # type: ignore
 
@@ -33,6 +34,11 @@ __protobuf__ = proto.module(
         'GetPortCallTimeseriesResponse',
         'TimeseriesGroup',
         'TimeseriesRow',
+        'GetVesselsInPortRequest',
+        'GetVesselsInPortResponse',
+        'VesselInPort',
+        'BerthStay',
+        'AnchorageStay',
     },
 )
 
@@ -293,10 +299,11 @@ class PortCall(proto.Message):
         unlocode (str):
             UNLOCODE of the port.
         berth_id (google.protobuf.wrappers_pb2.Int32Value):
-            Oceanbolt database identifier of the
-            berth/terminal.
+            Oceanbolt database identifier of the primary
+            berth/terminal visited during the port call.
         berth_name (str):
-            Name of the berth/terminal.
+            Name of the primary berth/terminal visited
+            during the port call.
         anchorage_id (google.protobuf.wrappers_pb2.Int32Value):
             Oceanbolt database identifier of the
             anchorage.
@@ -317,11 +324,11 @@ class PortCall(proto.Message):
         days_in_port (google.protobuf.wrappers_pb2.DoubleValue):
             Total duration of the port call (in days).
         days_waiting (google.protobuf.wrappers_pb2.DoubleValue):
-            Number of days the vessel was at berth in
-            during the duration of the port call.
-        days_at_berth (google.protobuf.wrappers_pb2.DoubleValue):
             Number of days the vessel was waiting at
             anchor before shifting to berth.
+        days_at_berth (google.protobuf.wrappers_pb2.DoubleValue):
+            Number of days the vessel was at berth in
+            during the duration of the port call.
         country_code (str):
             ISO 2-letter country code of the load
             country.
@@ -717,4 +724,388 @@ class TimeseriesRow(proto.Message):
     )
 
 
+class GetVesselsInPortRequest(proto.Message):
+    r"""Request object for GetVesselsInPort
+
+    Attributes:
+        port_id (int):
+            Database id of the port to filter on
+        unlocode (str):
+            UNLOCODE of the port to filter on
+        vessel_filter (oceanbolt.com.ptypes.filters.vessel_filter_pb2.VesselFilter):
+            Specifies vessel parameters to filter on.
+        timestamp (google.protobuf.timestamp_pb2.Timestamp):
+            Timestamp to generate the vessel in port list
+            for. This allows to generate historical
+            snapshots of the vessels that were inside a port
+            at a given time in history. If left blank, then
+            it the vessel list will default to be generated
+            for the current time.
+        merge_sequential_polygon_stays (bool):
+            Flag to indicate whether to merge sequential
+            berth stays in same berth (if the stays are
+            within the merge threshold). Default is false,
+            meaning that by default berth stays will not be
+            merged.
+        merge_threshold_hours (float):
+            The threshold in hours for a merge to take
+            place for multiple consequtive stays. If the
+            time from when the vessel left the berth until
+            it reentered into the same berth is above the
+            threshold, the polygon stays will not be merged.
+            Default value is 6 hours.
+    """
+
+    port_id = proto.Field(
+        proto.UINT32,
+        number=1,
+    )
+    unlocode = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    vessel_filter = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=vessel_filter_pb2.VesselFilter,
+    )
+    timestamp = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
+    merge_sequential_polygon_stays = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
+    merge_threshold_hours = proto.Field(
+        proto.DOUBLE,
+        number=6,
+    )
+
+
+class GetVesselsInPortResponse(proto.Message):
+    r"""Response object for GetVesselsInPort
+
+    Attributes:
+        vessels_in_port (int):
+            The number of vessels in port
+        data (Sequence[oceanbolt.com.portcalls_v3.types.VesselInPort]):
+            List of vessels in port at the requested
+            time.
+    """
+
+    vessels_in_port = proto.Field(
+        proto.UINT32,
+        number=1,
+    )
+    data = proto.RepeatedField(
+        proto.MESSAGE,
+        number=7,
+        message='VesselInPort',
+    )
+
+
+class VesselInPort(proto.Message):
+    r"""VesselInPort object
+
+    Attributes:
+        voyage_id (str):
+            Unique ID for the voyage. This can be shared
+            across multiple port calls in the case of
+            parceling voyages.
+        port_call_id (str):
+            Unique ID for the port call. This will always
+            be unique to the port call.
+        imo (int):
+            IMO number of the vessel.
+        vessel_name (str):
+            Name of the vessel.
+        port_id (google.protobuf.wrappers_pb2.Int32Value):
+            Oceanbolt database identifier of the port.
+        port_name (str):
+            Name of the port.
+        unlocode (str):
+            UNLOCODE of the port.
+        segment (str):
+            Segment of the vessel.
+        sub_segment (str):
+            Sub segment of the vessel.
+        dwt (float):
+            DWT of the vessel
+        berth_id (google.protobuf.wrappers_pb2.Int32Value):
+            Oceanbolt database identifier of the primary
+            berth/terminal visited during the port call.
+        berth_name (str):
+            Name of the primary berth/terminal visited
+            during the port call.
+        anchorage_id (google.protobuf.wrappers_pb2.Int32Value):
+            Oceanbolt database identifier of the
+            anchorage.
+        anchorage_name (str):
+            Name of the anchorage.
+        arrived_at (str):
+            UTC timestamp for when the vessel arrived at
+            the port.
+        departed_at (str):
+            UTC timestamp for when the vessel left the
+            port (only applies for historical snapshot
+            views), if blank, then the vessel is still
+            inside the port.
+        days_in_port (google.protobuf.wrappers_pb2.DoubleValue):
+            Total duration of the port call (in days).
+        country_code (str):
+            ISO 2-letter country code of the load
+            country.
+        operation (str):
+            Predicted operation type of the port call.
+        voyage_type (str):
+            Predicted the type of the voyage.
+        commodity (str):
+            Name of the predicted commodity.
+        commodity_value (str):
+            Database friendly name of the predicted
+            commodity.
+        commodity_group (str):
+            Name of the predicted commodity group.
+        volume (google.protobuf.wrappers_pb2.DoubleValue):
+            Volume loaded in metric tons.
+        port_visited (bool):
+            Flag to indicate whether the vessel has
+            visited the port interior. If the flag is false
+            the vessels only visited an anchorage or a
+            berth.
+        berth_stays (Sequence[oceanbolt.com.portcalls_v3.types.BerthStay]):
+            List of all berths that the vessel visited
+            during the port call
+        anchorage_stays (Sequence[oceanbolt.com.portcalls_v3.types.AnchorageStay]):
+            List of all anchorages that the vessel
+            visited during the port call
+        vessel_status (str):
+            Current Vessel status
+    """
+
+    voyage_id = proto.Field(
+        proto.STRING,
+        number=16,
+    )
+    port_call_id = proto.Field(
+        proto.STRING,
+        number=15,
+    )
+    imo = proto.Field(
+        proto.INT32,
+        number=1,
+    )
+    vessel_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    port_id = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=wrappers_pb2.Int32Value,
+    )
+    port_name = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    unlocode = proto.Field(
+        proto.STRING,
+        number=25,
+    )
+    segment = proto.Field(
+        proto.STRING,
+        number=18,
+    )
+    sub_segment = proto.Field(
+        proto.STRING,
+        number=19,
+    )
+    dwt = proto.Field(
+        proto.DOUBLE,
+        number=26,
+    )
+    berth_id = proto.Field(
+        proto.MESSAGE,
+        number=27,
+        message=wrappers_pb2.Int32Value,
+    )
+    berth_name = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    anchorage_id = proto.Field(
+        proto.MESSAGE,
+        number=28,
+        message=wrappers_pb2.Int32Value,
+    )
+    anchorage_name = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    arrived_at = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+    departed_at = proto.Field(
+        proto.STRING,
+        number=9,
+    )
+    days_in_port = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message=wrappers_pb2.DoubleValue,
+    )
+    country_code = proto.Field(
+        proto.STRING,
+        number=13,
+    )
+    operation = proto.Field(
+        proto.STRING,
+        number=14,
+    )
+    voyage_type = proto.Field(
+        proto.STRING,
+        number=17,
+    )
+    commodity = proto.Field(
+        proto.STRING,
+        number=20,
+    )
+    commodity_value = proto.Field(
+        proto.STRING,
+        number=21,
+    )
+    commodity_group = proto.Field(
+        proto.STRING,
+        number=22,
+    )
+    volume = proto.Field(
+        proto.MESSAGE,
+        number=23,
+        message=wrappers_pb2.DoubleValue,
+    )
+    port_visited = proto.Field(
+        proto.BOOL,
+        number=24,
+    )
+    berth_stays = proto.RepeatedField(
+        proto.MESSAGE,
+        number=29,
+        message='BerthStay',
+    )
+    anchorage_stays = proto.RepeatedField(
+        proto.MESSAGE,
+        number=30,
+        message='AnchorageStay',
+    )
+    vessel_status = proto.Field(
+        proto.STRING,
+        number=31,
+    )
+
+
+class BerthStay(proto.Message):
+    r"""BerthStay object
+
+    Attributes:
+        berth_id (int):
+            Berth id of the berth
+        berth_name (str):
+            Name of the berth
+        berth_type (str):
+            Type of the berth
+        arrived_at (str):
+            Timestamp of when the vessel arrived at the
+            berth
+        departed_at (str):
+            Timestamp of when the vessel departed from
+            the berth
+        draught_in (float):
+            The draught when the vessel arrived at the
+            berth
+        draught_out (float):
+            The draught when the vessel departed from the
+            berth
+        hours_in_berth (float):
+            The duration of the stay in the berth in
+            hours.
+    """
+
+    berth_id = proto.Field(
+        proto.UINT32,
+        number=1,
+    )
+    berth_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    berth_type = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    arrived_at = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    departed_at = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    draught_in = proto.Field(
+        proto.DOUBLE,
+        number=6,
+    )
+    draught_out = proto.Field(
+        proto.DOUBLE,
+        number=7,
+    )
+    hours_in_berth = proto.Field(
+        proto.DOUBLE,
+        number=8,
+    )
+
+
+class AnchorageStay(proto.Message):
+    r"""AnchorageStay object
+
+    Attributes:
+        anchorage_id (int):
+            Anchorage id of the anchorage
+        anchorage_name (str):
+            Name of the anchorage
+        arrived_at (str):
+            Timestamp of when the vessel arrived at the
+            anchorage
+        departed_at (str):
+            Timestamp of when the vessel departed from
+            the anchorage
+        hours_in_anchorage (float):
+            The duration of the stay in the anchorage in
+            hours.
+    """
+
+    anchorage_id = proto.Field(
+        proto.UINT32,
+        number=1,
+    )
+    anchorage_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    arrived_at = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    departed_at = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    hours_in_anchorage = proto.Field(
+        proto.DOUBLE,
+        number=5,
+    )
+
+
 __all__ = tuple(sorted(__protobuf__.manifest))
