@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,6 +17,8 @@
 from oceanbolt.com.vessels_v3.services.vessel_service.client import VesselServiceClient
 from oceanbolt.com.vessels_v3.services.vessel_service.async_client import VesselServiceAsyncClient
 
+from oceanbolt.com.vessels_v3.types.service import GetAisSummaryRequest
+from oceanbolt.com.vessels_v3.types.service import GetAisSummaryResponse
 from oceanbolt.com.vessels_v3.types.service import ListStoppageEventsRequest
 from oceanbolt.com.vessels_v3.types.service import ListStoppageEventsResponse
 from oceanbolt.com.vessels_v3.types.service import ListVesselsRequest
@@ -26,6 +28,8 @@ from oceanbolt.com.vessels_v3.types.service import Vessel
 
 __all__ = ('VesselServiceClient',
     'VesselServiceAsyncClient',
+    'GetAisSummaryRequest',
+    'GetAisSummaryResponse',
     'ListStoppageEventsRequest',
     'ListStoppageEventsResponse',
     'ListVesselsRequest',
