@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,6 +17,8 @@
 from .services.vessel_service import VesselServiceClient
 from .services.vessel_service import VesselServiceAsyncClient
 
+from .types.service import GetAisSummaryRequest
+from .types.service import GetAisSummaryResponse
 from .types.service import ListStoppageEventsRequest
 from .types.service import ListStoppageEventsResponse
 from .types.service import ListVesselsRequest
@@ -26,6 +28,8 @@ from .types.service import Vessel
 
 __all__ = (
     'VesselServiceAsyncClient',
+'GetAisSummaryRequest',
+'GetAisSummaryResponse',
 'ListStoppageEventsRequest',
 'ListStoppageEventsResponse',
 'ListVesselsRequest',
