@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -34,6 +34,7 @@ try:
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from google.protobuf import timestamp_pb2  # type: ignore
 from oceanbolt.com.vessels_v3.types import service
 from .transports.base import VesselServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import VesselServiceGrpcTransport
@@ -356,6 +357,7 @@ class VesselServiceClient(metaclass=VesselServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_vessels(self,
@@ -368,7 +370,6 @@ class VesselServiceClient(metaclass=VesselServiceClientMeta):
         r"""Vessels gets a list of vessels for the given filter
         parameters
 
-
         .. code-block:: python
 
             from oceanbolt.com import vessels_v3
@@ -486,6 +487,73 @@ class VesselServiceClient(metaclass=VesselServiceClientMeta):
         # Done; return the response.
         return response
 
+    def get_ais_summary(self,
+            request: Union[service.GetAisSummaryRequest, dict] = None,
+            *,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
+            timeout: float = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+            ) -> service.GetAisSummaryResponse:
+        r"""Generates summary data regarding AIS received during
+        a specific requested period for a single vessel
+
+        .. code-block:: python
+
+            from oceanbolt.com import vessels_v3
+
+            def sample_get_ais_summary():
+                # Create a client
+                client = vessels_v3.VesselServiceClient()
+
+                # Initialize request argument(s)
+                request = vessels_v3.GetAisSummaryRequest(
+                )
+
+                # Make the request
+                response = client.get_ais_summary(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.vessels_v3.types.GetAisSummaryRequest, dict]):
+                The request object. Request object for
+                GetAisSummaryRequest
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            oceanbolt.com.vessels_v3.types.GetAisSummaryResponse:
+                Request object for
+                GetAisSummaryResponse
+
+        """
+        # Create or coerce a protobuf request object.
+        # Minor optimization to avoid making a copy if the user passes
+        # in a service.GetAisSummaryRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, service.GetAisSummaryRequest):
+            request = service.GetAisSummaryRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.get_ais_summary]
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     def __enter__(self):
         return self
 
@@ -501,6 +569,9 @@ class VesselServiceClient(metaclass=VesselServiceClientMeta):
 
 
 
+
+
+
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
