@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -99,6 +99,7 @@ class VesselServiceGrpcAsyncIOTransport(VesselServiceTransport):
             quota_project_id=None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             always_use_jwt_access: Optional[bool] = False,
+            api_audience: Optional[str] = None,
             ) -> None:
         """Instantiate the transport.
 
@@ -194,6 +195,7 @@ class VesselServiceGrpcAsyncIOTransport(VesselServiceTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -277,6 +279,33 @@ class VesselServiceGrpcAsyncIOTransport(VesselServiceTransport):
             )
         return self._stubs['list_stoppage_events']
 
+    @property
+    def get_ais_summary(self) -> Callable[
+            [service.GetAisSummaryRequest],
+            Awaitable[service.GetAisSummaryResponse]]:
+        r"""Return a callable for the get ais summary method over gRPC.
+
+        Generates summary data regarding AIS received during
+        a specific requested period for a single vessel
+
+        Returns:
+            Callable[[~.GetAisSummaryRequest],
+                    Awaitable[~.GetAisSummaryResponse]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if 'get_ais_summary' not in self._stubs:
+            self._stubs['get_ais_summary'] = self.grpc_channel.unary_unary(
+                '/oceanbolt.com.vessels.v3.VesselService/GetAisSummary',
+                request_serializer=service.GetAisSummaryRequest.serialize,
+                response_deserializer=service.GetAisSummaryResponse.deserialize,
+            )
+        return self._stubs['get_ais_summary']
+
     def close(self):
         return self.grpc_channel.close()
 
