@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +14,8 @@
 # limitations under the License.
 #
 from .service import (
+    GetAisSummaryRequest,
+    GetAisSummaryResponse,
     ListStoppageEventsRequest,
     ListStoppageEventsResponse,
     ListVesselsRequest,
@@ -23,6 +25,8 @@ from .service import (
 )
 
 __all__ = (
+    'GetAisSummaryRequest',
+    'GetAisSummaryResponse',
     'ListStoppageEventsRequest',
     'ListStoppageEventsResponse',
     'ListVesselsRequest',
