@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,12 @@
 # limitations under the License.
 #
 import os
-import mock
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
 
 import grpc
 from grpc.experimental import aio
@@ -32,6 +37,7 @@ from google.api_core import path_template
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.oauth2 import service_account
+from google.protobuf import timestamp_pb2  # type: ignore
 from oceanbolt.com.vessels_v3.services.vessel_service import VesselServiceAsyncClient
 from oceanbolt.com.vessels_v3.services.vessel_service import VesselServiceClient
 from oceanbolt.com.vessels_v3.services.vessel_service import transports
@@ -65,20 +71,22 @@ def test__get_default_mtls_endpoint():
     assert VesselServiceClient._get_default_mtls_endpoint(non_googleapi) == non_googleapi
 
 
-@pytest.mark.parametrize("client_class", [
-    VesselServiceClient,
-    VesselServiceAsyncClient,
+@pytest.mark.parametrize("client_class,transport_name", [
+    (VesselServiceClient, "grpc"),
+    (VesselServiceAsyncClient, "grpc_asyncio"),
 ])
-def test_vessel_service_client_from_service_account_info(client_class):
+def test_vessel_service_client_from_service_account_info(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(service_account.Credentials, 'from_service_account_info') as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == 'api.oceanbolt.com:443'
+        assert client.transport._host == (
+            'api.oceanbolt.com:443'
+        )
 
 
 @pytest.mark.parametrize("transport_class,transport_name", [
@@ -97,23 +105,25 @@ def test_vessel_service_client_service_account_always_use_jwt(transport_class, t
         use_jwt.assert_not_called()
 
 
-@pytest.mark.parametrize("client_class", [
-    VesselServiceClient,
-    VesselServiceAsyncClient,
+@pytest.mark.parametrize("client_class,transport_name", [
+    (VesselServiceClient, "grpc"),
+    (VesselServiceAsyncClient, "grpc_asyncio"),
 ])
-def test_vessel_service_client_from_service_account_file(client_class):
+def test_vessel_service_client_from_service_account_file(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(service_account.Credentials, 'from_service_account_file') as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file("dummy/file/path.json", transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json("dummy/file/path.json", transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == 'api.oceanbolt.com:443'
+        assert client.transport._host == (
+            'api.oceanbolt.com:443'
+        )
 
 
 def test_vessel_service_client_get_transport_class():
@@ -161,6 +171,7 @@ def test_vessel_service_client_client_options(client_class, transport_class, tra
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -178,6 +189,7 @@ def test_vessel_service_client_client_options(client_class, transport_class, tra
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -195,6 +207,7 @@ def test_vessel_service_client_client_options(client_class, transport_class, tra
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT has
@@ -222,6 +235,23 @@ def test_vessel_service_client_client_options(client_class, transport_class, tra
             quota_project_id="octopus",
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
+        )
+    # Check the case api_endpoint is provided
+    options = client_options.ClientOptions(api_audience="https://language.googleapis.com")
+    with mock.patch.object(transport_class, '__init__') as patched:
+        patched.return_value = None
+        client = client_class(client_options=options, transport=transport_name)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file=None,
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            client_cert_source_for_mtls=None,
+            quota_project_id=None,
+            client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
+            api_audience="https://language.googleapis.com"
         )
 
 @pytest.mark.parametrize("client_class,transport_class,transport_name,use_client_cert_env", [
@@ -261,6 +291,7 @@ def test_vessel_service_client_mtls_env_auto(client_class, transport_class, tran
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case ADC client cert is provided. Whether client cert is used depends on
@@ -287,6 +318,7 @@ def test_vessel_service_client_mtls_env_auto(client_class, transport_class, tran
                         quota_project_id=None,
                         client_info=transports.base.DEFAULT_CLIENT_INFO,
                         always_use_jwt_access=True,
+                        api_audience=None,
                     )
 
     # Check the case client_cert_source and ADC client cert are not provided.
@@ -304,6 +336,7 @@ def test_vessel_service_client_mtls_env_auto(client_class, transport_class, tran
                     quota_project_id=None,
                     client_info=transports.base.DEFAULT_CLIENT_INFO,
                     always_use_jwt_access=True,
+                    api_audience=None,
                 )
 
 
@@ -381,6 +414,7 @@ def test_vessel_service_client_client_options_scopes(client_class, transport_cla
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 @pytest.mark.parametrize("client_class,transport_class,transport_name,grpc_helpers", [
@@ -405,6 +439,7 @@ def test_vessel_service_client_client_options_credentials_file(client_class, tra
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 def test_vessel_service_client_client_options_from_dict():
@@ -422,6 +457,7 @@ def test_vessel_service_client_client_options_from_dict():
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -447,6 +483,7 @@ def test_vessel_service_client_create_channel_credentials_file(client_class, tra
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # test that the credentials from file are saved and used as the credentials.
@@ -532,7 +569,6 @@ def test_list_vessels_empty_call():
         _, args, _ = call.mock_calls[0]
         assert args[0] == service.ListVesselsRequest()
 
-
 @pytest.mark.asyncio
 async def test_list_vessels_async(transport: str = 'grpc_asyncio', request_type=service.ListVesselsRequest):
     client = VesselServiceAsyncClient(
@@ -624,7 +660,6 @@ def test_list_stoppage_events_empty_call():
         _, args, _ = call.mock_calls[0]
         assert args[0] == service.ListStoppageEventsRequest()
 
-
 @pytest.mark.asyncio
 async def test_list_stoppage_events_async(transport: str = 'grpc_asyncio', request_type=service.ListStoppageEventsRequest):
     client = VesselServiceAsyncClient(
@@ -663,6 +698,101 @@ async def test_list_stoppage_events_async_from_dict():
     await test_list_stoppage_events_async(request_type=dict)
 
 
+@pytest.mark.parametrize("request_type", [
+  service.GetAisSummaryRequest,
+  dict,
+])
+def test_get_ais_summary(request_type, transport: str = 'grpc'):
+    client = VesselServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
+    )
+
+    # Everything is optional in proto3 as far as the runtime is concerned,
+    # and we are mocking out the actual API, so just send an empty request.
+    request = request_type()
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(
+            type(client.transport.get_ais_summary),
+            '__call__') as call:
+        # Designate an appropriate return value for the call.
+        call.return_value = service.GetAisSummaryResponse(
+            distance_traveled_nm=0.2107,
+            average_speed_knots=0.20090000000000002,
+            number_of_positions=2052,
+        )
+        response = client.get_ais_summary(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls) == 1
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == service.GetAisSummaryRequest()
+
+    # Establish that the response is the type that we expect.
+    assert isinstance(response, service.GetAisSummaryResponse)
+    assert math.isclose(response.distance_traveled_nm, 0.2107, rel_tol=1e-6)
+    assert math.isclose(response.average_speed_knots, 0.20090000000000002, rel_tol=1e-6)
+    assert response.number_of_positions == 2052
+
+
+def test_get_ais_summary_empty_call():
+    # This test is a coverage failsafe to make sure that totally empty calls,
+    # i.e. request == None and no flattened fields passed, work.
+    client = VesselServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport='grpc',
+    )
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(
+            type(client.transport.get_ais_summary),
+            '__call__') as call:
+        client.get_ais_summary()
+        call.assert_called()
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == service.GetAisSummaryRequest()
+
+@pytest.mark.asyncio
+async def test_get_ais_summary_async(transport: str = 'grpc_asyncio', request_type=service.GetAisSummaryRequest):
+    client = VesselServiceAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
+    )
+
+    # Everything is optional in proto3 as far as the runtime is concerned,
+    # and we are mocking out the actual API, so just send an empty request.
+    request = request_type()
+
+    # Mock the actual call within the gRPC stub, and fake the request.
+    with mock.patch.object(
+            type(client.transport.get_ais_summary),
+            '__call__') as call:
+        # Designate an appropriate return value for the call.
+        call.return_value =grpc_helpers_async.FakeUnaryUnaryCall(service.GetAisSummaryResponse(
+            distance_traveled_nm=0.2107,
+            average_speed_knots=0.20090000000000002,
+            number_of_positions=2052,
+        ))
+        response = await client.get_ais_summary(request)
+
+        # Establish that the underlying gRPC stub method was called.
+        assert len(call.mock_calls)
+        _, args, _ = call.mock_calls[0]
+        assert args[0] == service.GetAisSummaryRequest()
+
+    # Establish that the response is the type that we expect.
+    assert isinstance(response, service.GetAisSummaryResponse)
+    assert math.isclose(response.distance_traveled_nm, 0.2107, rel_tol=1e-6)
+    assert math.isclose(response.average_speed_knots, 0.20090000000000002, rel_tol=1e-6)
+    assert response.number_of_positions == 2052
+
+
+@pytest.mark.asyncio
+async def test_get_ais_summary_async_from_dict():
+    await test_get_ais_summary_async(request_type=dict)
+
+
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.VesselServiceGrpcTransport(
@@ -749,6 +879,15 @@ def test_transport_adc(transport_class):
         transport_class()
         adc.assert_called_once()
 
+@pytest.mark.parametrize("transport_name", [
+    "grpc",
+])
+def test_transport_kind(transport_name):
+    transport = VesselServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = VesselServiceClient(
@@ -781,6 +920,7 @@ def test_vessel_service_base_transport():
     methods = (
         'list_vessels',
         'list_stoppage_events',
+        'get_ais_summary',
     )
     for method in methods:
         with pytest.raises(NotImplementedError):
@@ -789,6 +929,14 @@ def test_vessel_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        'kind',
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_vessel_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -849,6 +997,28 @@ def test_vessel_service_transport_auth_adc(transport_class):
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.VesselServiceGrpcTransport,
+        transports.VesselServiceGrpcAsyncIOTransport,
+    ],
+)
+def test_vessel_service_transport_auth_gdch_credentials(transport_class):
+    host = 'https://language.com'
+    api_audience_tests = [None, 'https://language2.com']
+    api_audience_expect = [host, 'https://language2.com']
+    for t, e in zip(api_audience_tests, api_audience_expect):
+        with mock.patch.object(google.auth, 'default', autospec=True) as adc:
+            gdch_mock = mock.MagicMock()
+            type(gdch_mock).with_gdch_audience = mock.PropertyMock(return_value=gdch_mock)
+            adc.return_value = (gdch_mock, None)
+            transport_class(host=host, api_audience=t)
+            gdch_mock.with_gdch_audience.assert_called_once_with(
+                e
+            )
+
+
 @pytest.mark.parametrize(
     "transport_class,grpc_helpers",
     [
@@ -928,20 +1098,33 @@ def test_vessel_service_grpc_transport_client_cert_source_for_mtls(
             )
 
 
-def test_vessel_service_host_no_port():
+@pytest.mark.parametrize("transport_name", [
+    "grpc",
+    "grpc_asyncio",
+])
+def test_vessel_service_host_no_port(transport_name):
     client = VesselServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(api_endpoint='api.oceanbolt.com'),
+         transport=transport_name,
+    )
+    assert client.transport._host == (
+        'api.oceanbolt.com:443'
     )
-    assert client.transport._host == 'api.oceanbolt.com:443'
 
-
-def test_vessel_service_host_with_port():
+@pytest.mark.parametrize("transport_name", [
+    "grpc",
+    "grpc_asyncio",
+])
+def test_vessel_service_host_with_port(transport_name):
     client = VesselServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(api_endpoint='api.oceanbolt.com:8000'),
+        transport=transport_name,
+    )
+    assert client.transport._host == (
+        'api.oceanbolt.com:8000'
     )
-    assert client.transport._host == 'api.oceanbolt.com:8000'
 
 def test_vessel_service_grpc_transport_channel():
     channel = grpc.secure_channel('http://localhost/', grpc.local_channel_credentials())
@@ -1159,7 +1342,6 @@ def test_client_with_default_client_info():
         )
         prep.assert_called_once_with(client_info)
 
-
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = VesselServiceAsyncClient(
@@ -1171,6 +1353,7 @@ async def test_transport_close_async():
             close.assert_not_called()
         close.assert_called_once()
 
+
 def test_transport_close():
     transports = {
         "grpc": "_grpc_channel",
@@ -1226,4 +1409,5 @@ def test_api_key_credentials(client_class, transport_class):
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
